@@ -2,13 +2,15 @@ from .convert.xlsx import convert_to_xlsx, write_workbook
 from .convert.csv import convert_to_csv
 from .convert.json import convert_to_json
 from .services.services import Services
+from .commands.compare import ModelComparer
 
 
-__version__ = "0.3.27"
+__version__ = "0.3.28"
 __all__ = [
     "convert_to_csv",
     "convert_to_xlsx",
     "convert_to_json",
     "Services",
     "write_workbook",
+    "ModelComparer",
 ]
