@@ -1,10 +1,7 @@
-import os
-
 import click
-import toml
 
-from .commands import to_csv, to_xlsx, to_json, config
-from .commons.endpoints import default_endpoints
+from .commands import to_csv, to_xlsx, to_json, compare
+from .commons.consts import default_endpoints
 from . import __version__
 
 
@@ -16,13 +13,6 @@ def print_version(ctx, param, value):
 
 
 @click.group()
-@click.option(
-    "-c",
-    "--config-file",
-    type=click.Path(),
-    default="~/.hycli/config.toml",
-    show_default=True,
-)
 @click.option(
     "-v",
     "--version",
@@ -64,51 +54,33 @@ def print_version(ctx, param, value):
     help="extractor endpoint header(s) can be multiple. Similair to curl, e.g. -H 'keyheader: value' -H '2ndkeyheader: 2ndvalue'",
 )
 @click.pass_context
-def main(ctx, config_file, endpoint_env, username, password, extractor, header):
+def main(ctx, endpoint_env, username, password, extractor, header):
     """
-    Can convert 1 invoice to xml or a directory of invoices to csv/xlsx.
-    It is advised to configurate credentials and endpoints before use with: \n >> hycli config
+    Can extract information from a directory of documents (invoices, receipts) to csv/xlsx using the Hypatos Extraction service.
     """
-    filename = os.path.expanduser(config_file)
     ctx.obj = {
-        "config_file": filename,
         "env": endpoint_env,
         "headers": {h.split(":")[0].strip(): h.split(":")[1].strip() for h in header},
     }
 
-    try:
-        with open(filename) as cfg:
-            conf = toml.loads(cfg.read())
-
-        ctx.obj["config"] = conf[endpoint_env]
-
-    except (FileNotFoundError, KeyError):
-        click.echo(
-            f"No configuration found, using default endpoints for {endpoint_env} environment."
-        )
-        click.echo("Define custom endpoints for environment with: >> hycli config \n")
-        ctx.obj["config"] = {
-            "endpoints": {
-                k: v
-                for k, v in default_endpoints[endpoint_env].items()
-                if v is not None
-            }
-        }
+    ctx.obj["endpoints"] = {
+        k: v for k, v in default_endpoints[endpoint_env].items() if v is not None
+    }
 
     if username:
-        ctx.obj["config"]["username"] = username
+        ctx.obj["username"] = username
 
     if password:
-        ctx.obj["config"]["password"] = password
+        ctx.obj["password"] = password
 
     if extractor:
-        ctx.obj["config"]["endpoints"]["extractor"] = extractor
+        ctx.obj["endpoints"]["extractor"] = extractor
 
 
 main.add_command(to_csv.to_csv)
 main.add_command(to_xlsx.to_xlsx)
 main.add_command(to_json.to_json)
-main.add_command(config.config)
+main.add_command(compare.compare)
 
 if __name__ == "__main__":
     main()
