@@ -12,8 +12,15 @@ from .. import convert_to_json, Services
     "--output",
     help="output path for json files absolute or relative from current location.",
 )
+@click.option(
+    "-s",
+    "--skip",
+    is_flag=True,
+    default=False,
+    help="Skip converting documents which are found to have been converted in output path.",
+)
 @click.pass_context
-def to_json(ctx, path, workers, output):
+def to_json(ctx, path, workers, output, skip):
     """ Convert invoices to jsons """
     # Services available
     spinner = Halo(spinner="dots")
@@ -22,7 +29,7 @@ def to_json(ctx, path, workers, output):
     spinner.succeed(f"Found dir: {path}\n ")
 
     # Conversion
-    skipped_files = convert_to_json(path, services, workers, output)
+    skipped_files = convert_to_json(path, services, workers, output, skip)
 
     if skipped_files:
         spinner.fail("Could not convert all invoice(s) to json output.")
