@@ -1,19 +1,20 @@
 import os
-import itertools
 import re
+import json
+import itertools
 
 from concurrent.futures import ThreadPoolExecutor, as_completed
 from pathlib import Path
 
 import click
-from filetype import guess
+from filetype import guess_mime
 
-from ..services.requests import extract_invoice, validation, validate_vat
+from ..services.requests import extract_invoice
 
 
 def run_requests(workers: int, path: str, services) -> dict:
     files = get_filenames(path)
-    result, vat_validation_result = {}, {}
+    result = {}
 
     with ThreadPoolExecutor(max_workers=workers) as exe:
         jobs = {
@@ -26,29 +27,17 @@ def run_requests(workers: int, path: str, services) -> dict:
                 services.headers,
             ): file_path
             for file_path, file_extension in files.items()
+            if not file_extension.endswith("json")
         }
         label = f"Converting {len(jobs)} invoices"
 
         with click.progressbar(jobs, label=label) as bar:
             for idx, future in enumerate(as_completed(jobs)):
                 file_name = jobs[future].split("/")[-1]
-                validated_invoice = None
 
                 try:
                     extracted_invoice = future.result(timeout=300)
-
-                    if getattr(services, "validation_endpoint", None):
-                        validated_invoice = validation(
-                            extracted_invoice, services.validation_endpoint
-                        )
-
-                    if getattr(services, "vat_validation_endpoint", None):
-                        vat_validation_result[idx] = validate_vat(
-                            extracted_invoice, services.vat_validation_endpoint
-                        )
-                        vat_validation_result[idx]["file_name"] = file_name
-
-                    result[idx] = flatten_invoice(extracted_invoice, validated_invoice,)
+                    result[idx] = flatten_invoice(extracted_invoice)
                 except Exception as e:
                     result[idx] = {"error_message": (str(e), None, None)}
                 finally:
@@ -56,23 +45,38 @@ def run_requests(workers: int, path: str, services) -> dict:
 
                 bar.update(1)
 
+        json_jobs = {
+            file_path: json.loads(file_path.read_bytes())
+            for file_path, file_extension in files.items()
+            if file_extension.endswith("json")
+        }
+        label = f"Merging {len(json_jobs)} invoices"
+
+        with click.progressbar(json_jobs, label=label) as bar:
+            for idx, (file_path, document) in enumerate(
+                json_jobs.items(), start=len(jobs)
+            ):
+                result[idx] = flatten_invoice(document)
+                result[idx]["file_name"] = (file_path.name, None, None)
+
+                bar.update(1)
+
     if not result:
         quit("No files found in path")
-    return (result, vat_validation_result)
+    return result
 
 
-def flatten_invoice(invoice, validation):
+def flatten_invoice(invoice):
     return_dict = dict()
     entities = invoice["entities"]
     probabilities = invoice.get("probabilities")
 
-    def traverse_items(entities, probabilities, validation, _dict, *prefix):
+    def traverse_items(entities, probabilities, _dict, *prefix):
         for k, v in entities.items():
             if isinstance(v, dict):
                 traverse_items(
                     entities[k],
                     probabilities[k] if probabilities else None,
-                    validation[k][0] if validation and k in validation else None,
                     return_dict,
                     k,
                 )
@@ -86,11 +90,6 @@ def flatten_invoice(invoice, validation):
                         traverse_items(
                             temp_dict,
                             probabilities[k][counter] if probabilities else None,
-                            validation[k][0][str(counter)][0]
-                            if validation
-                            and k in validation
-                            and str(counter) in validation[k][0]
-                            else None,
                             return_dict,
                         )
                 # ibanAll enc
@@ -128,15 +127,8 @@ def flatten_invoice(invoice, validation):
                         _dict[field_name] = (v if v else "", None, None)
                 else:
                     _dict[field_name] = (v if v else "", None, None)
-                if validation:
-                    if original_k in validation:
-                        _dict[field_name] = (
-                            v if v else "",
-                            None,
-                            validation[original_k],
-                        )
 
-    traverse_items(entities, probabilities, validation, return_dict)
+    traverse_items(entities, probabilities, return_dict)
     return return_dict
 
 
@@ -147,17 +139,45 @@ def read_pdf(pdf_path: str) -> bytes:
     return pdf
 
 
-def get_filenames(path: str) -> list:
-    types = ("*.pdf", "*.tif", "*.tiff", "*.png", "*.jpg")
-    abs_path = os.path.join(os.getcwd(), path)
-    files_grabbed = []
+def get_filenames(
+    input_path: str, output_path: str = None, skipped: bool = False
+) -> dict:
+    """Find all filepaths needed to be processed
 
-    for files in types:
-        files_grabbed.extend(Path(abs_path).rglob(files))
-        files_grabbed.extend(Path(abs_path).rglob(files.upper()))
+    Args:
+        input_path (str): [description]
+        output_path (str): [description]
+        skipped (bool): [description]
 
-    files_grabbed = [str(f) for f in files_grabbed]
-    return {f: guess(f).mime for f in files_grabbed if guess(f).mime}
+    Returns:
+        list: files found in input_path
+    """
+    abs_input_path = os.path.join(os.getcwd(), input_path)
+    f_types = ("*.pdf", "*.tif", "*.tiff", "*.png", "*.jpg")
+
+    found_files = []
+    skippable_files = []
+
+    for f_type in f_types:
+        found_files.extend(Path(abs_input_path).rglob(f_type))
+        found_files.extend(Path(abs_input_path).rglob(f_type.upper()))
+
+    if skipped:
+        skippable_files.extend(Path(output_path).rglob("*.json"))
+        skippable_files = [f.stem for f in skippable_files]
+        found_files = [x for x in found_files if x.stem not in skippable_files]
+
+    # TODO: write fix for non mime recognized files
+    # Currently only mime recognized files are processed
+    found_files = [str(f) for f in found_files]
+
+    if any([f.endswith(".json") for f in found_files]):
+        return {f: guess_mime(f) for f in found_files if guess_mime(f)}
+    else:
+        return {
+            **{f: guess_mime(f) for f in found_files if guess_mime(f)},
+            **{f: "application/json" for f in Path(abs_input_path).rglob("*.json")},
+        }
 
 
 def structure_sheets(response: dict, header_sheetname="header"):
