@@ -14,7 +14,7 @@ def convert_to_csv(
     probability=False,
 ):
     # Get requests result
-    result, _ = run_requests(workers, input_path, services)
+    result = run_requests(workers, input_path, services)
     processed_dir_name = os.path.normpath(output_path).split(os.path.sep)[-1]
 
     # Structure result
