@@ -5,7 +5,7 @@ import pandas as pd
 import numpy as np
 
 from .commons import run_requests, structure_sheets, structure_sheet
-from .consts import RED_TO_GREEN_GRADIENT
+from ..commons.consts import RED_TO_GREEN_GRADIENT
 from ..services.services import Services
 
 
@@ -21,20 +21,18 @@ def convert_to_xlsx(
     project directory. Every key, value pair from Invoice Extractor will flattened
     into the following tuple:
 
-        key = (value, probability, validation[optional])
+        key = (value, probability)
 
     Arguments:
         path {str} -- Path to the directory containing invoices, uses rglob.
         extractor_endpoint {str} -- Url of Hypatos extractor service.
 
     Keyword Arguments:
-        vat_validator_endpoint {str} -- Url of vat_validator. (default: {None})
-        validation_endpoint {str} -- Url of validation. (default: {None})
         token {str} -- API token. (default: {None})
         workers {int} -- Amount of multithread. (default: {1})
     """
     # Get requests result
-    response, vat_validation_result = run_requests(workers, input_path, services)
+    response = run_requests(workers, input_path, services)
 
     # Structure response into sheets (dict) containing records [{...}, {...}]
     sheets = structure_sheets(response)
@@ -45,14 +43,10 @@ def convert_to_xlsx(
             sheets[sheet] = normalize_probability(sheets[sheet])
 
     # Write sheets into workbook
-    write_workbook(
-        output_path, sheets, vat_validation_result, bool(services.validation_endpoint),
-    )
+    write_workbook(output_path, sheets)
 
 
-def write_workbook(
-    output_path: str, sheets: List[dict], vat_validation=None, validation: bool = False,
-):
+def write_workbook(output_path: str, sheets: List[dict]):
     # Init workbook/sheets
     workbook = xlsxwriter.Workbook(output_path)
 
@@ -69,25 +63,16 @@ def write_workbook(
         write_sheet(
             workbook.get_worksheet_by_name(sheet),
             structure_sheet(sheets[sheet]),
-            validation,
             header_format,
             number_format,
             probability_formats,
         )
 
-    if vat_validation:
-        write_vat_validation(vat_validation, workbook)
-
     workbook.close()
 
 
 def write_sheet(
-    worksheet,
-    records: list,
-    validation: bool,
-    header_format,
-    number_format,
-    probability_formats: list,
+    worksheet, records: list, header_format, number_format, probability_formats: list
 ):
     """Write items to workbook sheet.
 
@@ -96,7 +81,6 @@ def write_sheet(
         records {[type]} -- [description]
         bold_header {[type]} -- [description]
         red_to_green_formats {[type]} -- [description]
-        validation {[type]} -- [description]
     """
     for idx, row in enumerate(records):
         count = 0
@@ -105,7 +89,7 @@ def write_sheet(
             if not isinstance(value, tuple):
                 records[idx][key] = (value, None, None)
 
-            column_value, probability, validation_errors = records[idx][key]
+            column_value, probability, _ = records[idx][key]
             value_format = number_format if isinstance(column_value, float) else None
 
             if pd.notna(probability):
@@ -115,16 +99,6 @@ def write_sheet(
             else:
                 worksheet.write(idx + 1, count, column_value, value_format)
 
-            if validation and key not in ["file_name", "error_message", "row_number"]:
-                validation_errors = validation_errors if validation_errors else 0
-                count += 1
-                worksheet.write(0, count, f"{key}ValidationErrors", header_format)
-                if validation_errors == 0:
-                    worksheet.write(idx + 1, count, validation_errors)
-                else:
-                    worksheet.write(idx + 1, count, len(validation_errors))
-                    worksheet.write_comment(idx + 1, count, str(validation_errors))
-
             count += 1
 
     for i, width in enumerate(get_col_widths(pd.DataFrame.from_records(records))):
@@ -145,18 +119,6 @@ def get_col_widths(invoices, max_col_width=70):
     ]
 
 
-def write_vat_validation(result, workbook):
-    workbook.add_worksheet("vat_validation")
-    worksheet = workbook.get_worksheet_by_name("vat_validation")
-
-    for idx, row in result.items():
-        count = 0
-        for key, value in row.items():
-            worksheet.write(0, count, key)
-            worksheet.write(idx + 1, count, value)
-            count += 1
-
-
 def normalize_probability(records: list):
     """ Normalize the probabilities for every column inbetween range(min, max) of
     particulair column.
