@@ -46,27 +46,3 @@ def extract_invoice(
 
     response.raise_for_status()
     return response.json()
-
-
-@handle_status_code
-def validation(extracted_invoice, endpoint_url):
-    """ Request validaton service """
-    response = requests.post(
-        url=endpoint_url,
-        json=extracted_invoice,
-        headers={"Content-type": "application/json"},
-    )
-    response.raise_for_status()
-    return response.json()
-
-
-@handle_status_code
-def validate_vat(extracted_invoice, endpoint_url):
-    """ Request vat validator """
-    response = requests.post(
-        url=endpoint_url,
-        json=extracted_invoice,
-        headers={"Content-type": "application/json"},
-    )
-    response.raise_for_status()
-    return response.json()
