@@ -10,25 +10,20 @@ from .requests import request_token
 class Services(object):
     def __init__(self, ctx, check_up=False):
         """
-        TODO: put correct endpoints to check if online
-        extractor: '/'
-        vat_validator: https://github.com/hypatos/vat-validator/pull/36
+        Holds attributes related to service.
         """
-        config = ctx.obj["config"]
-        endpoints = config["endpoints"]
+        endpoints = ctx.obj.get("endpoints")
 
         self.env = ctx.obj.get("env")
         self.headers = ctx.obj.get("headers")
-        self.username = config.get("username")
-        self.password = config.get("password")
+        self.username = ctx.obj.get("username")
+        self.password = ctx.obj.get("password")
         self.authentication_endpoint = endpoints.get("authentication")
 
         if check_up:
             self.are_up(endpoints, ctx)
 
         self.extractor_endpoint = endpoints.get("extractor")
-        self.vat_validator_endpoint = endpoints.get("vat_validation")
-        self.validation_endpoint = endpoints.get("validation")
 
         self.token = None
         self.token_counter = 0
